from .pycritty import parser, subparsers
from .ls import list_parser
from .save import save_parser
from .load import load_parser
from .install import install_parser
from .rm import remove_parser
